pub fn LiquidMenuAbsorbedIconButton(
__arg0: Modifier,
__arg1: GlassButtonSpec,
__arg2: f32,
__arg3: bool,
on_click: impl Fn() + 'static,
__arg5: &'static str,
)Expand description
A neighboring glass icon source that keeps its material mounted while an open menu owns and deforms its foreground.